@@ -13,8 +13,8 @@ class Invertible[T](Protocol):
 
 @dataclass(repr=False, eq=False, frozen=True, slots=True)
 class SimpleInvertible[T](Invertible[T]):
-    callable: Callable[..., T]
+    getter: Callable[..., T]
 
     @override
     def __invert__(self) -> T:
-        return self.callable()
+        return self.getter()
